import os
from moviepy import VideoFileClip

def mp4_to_mp3(mp4_file, mp3_file):
    """
    Diese Funktion nimmt eine MP4-Datei und extrahiert den Audioteil, um ihn als MP3-Datei zu speichern.
    
    :param mp4_file: Der Pfad zur MP4-Datei, die konvertiert werden soll.
    :param mp3_file: Der Pfad, an dem die MP3-Datei gespeichert werden soll.
    """
    # Lade die MP4-Datei und erstelle ein VideoFileClip-Objekt
    video = VideoFileClip(mp4_file)
    
    # Extrahiere die Audiospur des Videos
    audio = video.audio
    
    # Speichere die Audiospur als MP3-Datei
    audio.write_audiofile(mp3_file)

    # Schließe die Audio- und Videoobjekte, um Ressourcen freizugeben
    audio.close()
    video.close()

if __name__ == "__main__":
    """
    Hauptfunktion des Skripts:
    - Geht alle Dateien im aktuellen Arbeitsverzeichnis durch und sucht nach MP4-Dateien.
    - Für jede MP4-Datei wird eine gleichnamige MP3-Datei erstellt.
    """
    # Hole den aktuellen Arbeitsordner (dort, wo das Skript liegt)
    current_directory = os.path.dirname(os.path.abspath(__file__))
    
    # Gehe alle Dateien im Ordner durch
    for filename in os.listdir(current_directory):
        if filename.endswith(".mp4"):  # Überprüfe, ob die Datei eine MP4-Datei ist
            mp4_file = os.path.join(current_directory, filename)  # MP4-Dateipfad
            mp3_file = os.path.join(current_directory, filename.replace(".mp4", ".mp3"))  # MP3-Dateipfad
            
            # Rufe die Funktion auf, um die MP4-Datei zu MP3 zu konvertieren
            mp4_to_mp3(mp4_file, mp3_file)
            print(f"Die Datei {filename} wurde erfolgreich zu {mp3_file} konvertiert.")

